@@ -86,7 +86,7 @@ class GenericGroupCrud(MethodView):
         return vmg.generic_update_or_create(self.model, self.validator)
 
 
-def register_api(app, model, name, validator, schema):
+def register_api(app, db, model, name, validator, schema):
     """
     Register API method
     :param schema:
@@ -96,7 +96,7 @@ def register_api(app, model, name, validator, schema):
     :param name:
     :return:
     """
-    item = GenericItemCrud.as_view(f"{name}-item", model, validator, schema)
-    group = GenericGroupCrud.as_view(f"{name}-group", model, validator, schema)
+    item = GenericItemCrud.as_view(f"{name}-item", db, model, validator, schema)
+    group = GenericGroupCrud.as_view(f"{name}-group", db, model, validator, schema)
     app.add_url_rule(f"/{name}/<int:id>", view_func=item)
     app.add_url_rule(f"/{name}/", view_func=group)
